require "smarthr/version"

module SmartHR
  autoload :Client, "smarthr/client"
  autoload :Converter, "smarthr/converter"

  class Error < StandardError
    def self.from_response(status, body)
      APIConnectionError.new("Invalid response #{body.to_hash} (status: #{status})")
    end

    attr_reader :status
    attr_reader :error_response

    def initialize(message, status = nil, error_response = nil)
      @status = status
      @error_response = error_response
      super(message)
    end
  end

  class APIConnectionError < SmartHR::Error
    def self.faraday_error(e)
      new("Connection with SmartHR API server failed. #{e.message}", e)
    end

    attr_reader :original_error

    def initialize(message, original_error = nil)
      @original_error = original_error

      if original_error && original_error.response.is_a?(Hash)
        super(message, original_error.response[:status], original_error.response[:body])
      else
        super(message)
      end
    end
  end
end
