module SmartHR::Client::BizEstablishmentMethods
  # Get the list of business establishments
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E4%BA%8B%E6%A5%AD%E6%89%80/getV1BizEstablishments
  #
  # @param page                [Integer]
  # @param per_page            [Integer]
  # @param embed_soc_ins_owner [Boolean] Whether or not to embed social insurance owner
  # @param embed_lab_ins_owner [Boolean] Whether or not to embed labor insurance owner
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Array<Hashie::Mash>] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Array<Hashie::Mash>]
  def get_biz_establishments(page: 1, per_page: 10, embed_soc_ins_owner: false, embed_lab_ins_owner: false, &block)
    embed = embed_soc_ins_owner ? 'soc_ins_owner' : nil
    embed = embed_lab_ins_owner ? 'lab_ins_owner' : nil

    get("/biz_establishments",
      page: page,
      per_page: per_page,
      embed: embed,
      &block
    )
  end
end
