module SmartHR::Client::CrewCustomFieldTemplateMethods
  # Delete the crew custom field template
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%BE%93%E6%A5%AD%E5%93%A1%E3%82%AB%E3%82%B9%E3%82%BF%E3%83%A0%E9%A0%85%E7%9B%AE%E3%83%86%E3%83%B3%E3%83%97%E3%83%AC%E3%83%BC%E3%83%88/deleteV1CrewCustomFieldTemplatesId
  #
  # @param id [String]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  def destroy_crew_custom_field_template(id:, &block)
    delete("/crew_custom_field_templates/#{id}", &block)
  end

  # Get the crew custom field template
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%BE%93%E6%A5%AD%E5%93%A1%E3%82%AB%E3%82%B9%E3%82%BF%E3%83%A0%E9%A0%85%E7%9B%AE%E3%83%86%E3%83%B3%E3%83%97%E3%83%AC%E3%83%BC%E3%83%88/getV1CrewCustomFieldTemplatesId
  #
  # @param id          [String]
  # @param embed_group [Boolean] Whether or not to embed group
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def find_crew_custom_field_template(id:, embed_group: false, &block)
    get("/crew_custom_field_templates/#{id}", embed: embed_group ? 'group' : nil, &block)
  end

  # Change the data of the specified template
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%BE%93%E6%A5%AD%E5%93%A1%E3%82%AB%E3%82%B9%E3%82%BF%E3%83%A0%E9%A0%85%E7%9B%AE%E3%83%86%E3%83%B3%E3%83%97%E3%83%AC%E3%83%BC%E3%83%88/patchV1CrewCustomFieldTemplatesId
  #
  # @param id   [String]
  # @param body [Hash]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def update_crew_custom_field_template(id:, body:, &block)
    patch("/crew_custom_field_templates/#{id}", body, &block)
  end

  # Get the list of crew custom field templates
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%BE%93%E6%A5%AD%E5%93%A1%E3%82%AB%E3%82%B9%E3%82%BF%E3%83%A0%E9%A0%85%E7%9B%AE%E3%83%86%E3%83%B3%E3%83%97%E3%83%AC%E3%83%BC%E3%83%88/getV1CrewCustomFieldTemplates
  #
  # @param page        [Integer]
  # @param per_page    [Integer]
  # @param embed_group [Boolean] Whether or not to embed group
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Array<Hashie::Mash>] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Array<Hashie::Mash>]
  def get_crew_custom_field_templates(page: 1, per_page: 10, embed_group: false, &block)
    get("/crew_custom_field_templates",
      page: page,
      per_page: per_page,
      embed: embed_group ? 'group' : nil,
      &block
    )
  end

  # Create a new crew custom field template
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%BE%93%E6%A5%AD%E5%93%A1%E3%82%AB%E3%82%B9%E3%82%BF%E3%83%A0%E9%A0%85%E7%9B%AE%E3%83%86%E3%83%B3%E3%83%97%E3%83%AC%E3%83%BC%E3%83%88/postV1CrewCustomFieldTemplates
  #
  # @param body [Hash]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def create_crew_custom_field_template(body:, &block)
    post("/crew_custom_field_templates", body, &block)
  end
end
