module SmartHR::Client::CrewInputFormMethods
  # Get the crew input form
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%BE%93%E6%A5%AD%E5%93%A1%E6%83%85%E5%A0%B1%E5%8F%8E%E9%9B%86%E3%83%95%E3%82%A9%E3%83%BC%E3%83%A0/getV1CrewInputFormsId
  #
  # @param id                [String]
  # @param embed_mail_format [Boolean] Whether or not to embed mail format
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def find_crew_input_form(id:, embed_mail_format: false, &block)
    get("/crew_input_forms/#{id}", embed: embed_mail_format ? 'mail_format' : nil, &block)
  end

  # Get the list of crew input forms
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E5%BE%93%E6%A5%AD%E5%93%A1%E6%83%85%E5%A0%B1%E5%8F%8E%E9%9B%86%E3%83%95%E3%82%A9%E3%83%BC%E3%83%A0/getV1CrewInputForms
  #
  # @param page              [Integer]
  # @param per_page          [Integer]
  # @param embed_mail_format [Boolean] Whether or not to embed mail format
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Array<Hashie::Mash>] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Array<Hashie::Mash>]
  def get_crew_input_forms(page: 1, per_page: 10, embed_mail_format: false, &block)
    get("/crew_input_forms",
      page: page,
      per_page: per_page,
      embed: embed_mail_format ? 'mail_format' : nil,
      &block
    )
  end
end
