module SmartHR::Client::DependentRelationMethods
  # Get the list of dependent relations
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E7%B6%9A%E6%9F%84/getV1DependentRelations
  #
  # @param page          [Integer]
  # @param per_page      [Integer]
  # @param filter_spouse [Boolean] Whether or not to filter spouse
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Array<Hashie::Mash>] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Array<Hashie::Mash>]
  def get_dependent_relations(page: 1, per_page: 10, filter_spouse: false, &block)
    get("/dependent_relations",
      page: page,
      per_page: per_page,
      filter: filter_spouse ? 'spouse' : nil,
      &block
    )
  end
end
