module SmartHR::Client::EmploymentTypeMethods
  # Delete the crew custom field template group
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E9%9B%87%E7%94%A8%E5%BD%A2%E6%85%8B/deleteV1EmploymentTypesId
  #
  # @param id [String]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  def destroy_employment_type(id:, &block)
    delete("/employment_types/#{id}", &block)
  end

  # Get the employment type
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E9%9B%87%E7%94%A8%E5%BD%A2%E6%85%8B/getV1EmploymentTypesId
  #
  # @param id [String]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def find_employment_type(id:, &block)
    get("/employment_types/#{id}", &block)
  end

  # Change the data of the specified group
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E9%9B%87%E7%94%A8%E5%BD%A2%E6%85%8B/patchV1EmploymentTypesId
  #
  # @param id   [String]
  # @param body [Hash]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def update_employment_type(id:, body:, &block)
    patch("/employment_types/#{id}", body, &block)
  end

  # Get the list of employment types
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E9%9B%87%E7%94%A8%E5%BD%A2%E6%85%8B/getV1EmploymentTypes
  #
  # @param page            [Integer]
  # @param per_page        [Integer]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Array<Hashie::Mash>] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Array<Hashie::Mash>]
  def get_employment_types(page: 1, per_page: 10, &block)
    get("/employment_types",
      page: page,
      per_page: per_page,
      &block
    )
  end

  # Create a new employment type
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E9%9B%87%E7%94%A8%E5%BD%A2%E6%85%8B/postV1EmploymentTypes
  #
  # @param body [Hash]
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def create_employment_type(body:, &block)
    post("/employment_types", body, &block)
  end
end
