module SmartHR::Client::UserMethods
  # Get the user
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E3%83%A6%E3%83%BC%E3%82%B6/getV1UsersId
  #
  # @param id         [String]
  # @param embed_crew [Boolean] Whether or not to embed crews
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Hashie::Mash] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Hashie::Mash]
  def find_user(id:, embed_crew: false, &block)
    get("/users/#{id}", embed: embed_crew ? 'crew' : nil, &block)
  end

  # Get the list of users
  #
  # @see https://developer.smarthr.jp/api/index.html#!/%E3%83%A6%E3%83%BC%E3%82%B6/getV1Users
  #
  # @param page       [Integer]
  # @param per_page   [Integer]
  # @param embed_crew [Boolean] Whether or not to embed crews
  #
  # @yield [response_body, response_header] if block was given, return response body and response header through block arguments
  # @yieldparam response_body [Array<Hashie::Mash>] response body
  # @yieldparam response_header [Hash<String, String>] response header (e.g. X-Rate-Limit-Limit, X-Rate-Limit-Reset, X-Rate-Limit-Remaining)
  #
  # @return [Array<Hashie::Mash>]
  def get_users(page: 1, per_page: 10, embed_crew: false, &block)
    get("/users",
      page: page,
      per_page: per_page,
      embed: embed_crew ? 'crew' : nil,
      &block
    )
  end
end
